// rollup.config.js
import resolve from 'rollup-plugin-node-resolve';
import babel from 'rollup-plugin-babel';
import commonjs from 'rollup-plugin-commonjs';

import postcss from 'rollup-plugin-postcss';
import simplevars from 'postcss-simple-vars';
import nested from 'postcss-nested'; 
import cssnext from 'postcss-cssnext';
import cssnano from 'cssnano';


export default {
  input: 'src/entry.js',
  output: [
    {
      file: 'build/bundle.amd.js',
      format: 'amd'
    },
    {
      file: 'build/bundle.cjs.js',
      format: 'cjs'
    },
    {
      file: 'build/bundle.es.js',
      format: 'es'
    },
    {
      file: 'build/bundle.iife.js',
      format: 'iife'
    },    
    {
      file: 'build/bundle.umd.js',
      format: 'umd'
    },    
  ],
  external: ['jquery'],
  globals: {
    jquery: 'jquery'
  },
  plugins: [
    postcss({ 
      plugins: [ 
        simplevars(),
        nested(), 
        cssnext({ warnForDuplicates: false, }), 
        cssnano(),
      ],
      extensions: [ '.css' ]
    }),
    commonjs(),
    resolve({
      jsnext: true,
    }),
    babel({
      exclude: 'node_modules/**' // only transpile our source code
    }),
  ]
};